==> aliyun-python-sdk-dms-enterprise-1.5.0.tar.gz: aliyun-python-sdk-dms-enterprise-1.5.0/aliyunsdkdms_enterprise/request/v20181101/ListOrdersRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdms_enterprise.endpoint import endpoint_data

class ListOrdersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dms-enterprise', '2018-11-01', 'ListOrders','dmsenterprise')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_OrderStatus(self):
		return self.get_query_params().get('OrderStatus')

	def set_OrderStatus(self,OrderStatus):
		self.add_query_param('OrderStatus',OrderStatus)

	def get_SearchContent(self):
		return self.get_query_params().get('SearchContent')

	def set_SearchContent(self,SearchContent):
		self.add_query_param('SearchContent',SearchContent)

	def get_SearchDateType(self):
		return self.get_query_params().get('SearchDateType')

	def set_SearchDateType(self,SearchDateType):
		self.add_query_param('SearchDateType',SearchDateType)

	def get_EndTime(self):
		return self.get_query_params().get('EndTime')

	def set_EndTime(self,EndTime):
		self.add_query_param('EndTime',EndTime)

	def get_StartTime(self):
		return self.get_query_params().get('StartTime')

	def set_StartTime(self,StartTime):
		self.add_query_param('StartTime',StartTime)

	def get_Tid(self):
		return self.get_query_params().get('Tid')

	def set_Tid(self,Tid):
		self.add_query_param('Tid',Tid)

	def get_PageNumber(self):
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_query_param('PageNumber',PageNumber)

	def get_PluginType(self):
		return self.get_query_params().get('PluginType')

	def set_PluginType(self,PluginType):
		self.add_query_param('PluginType',PluginType)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_OrderResultType(self):
		return self.get_query_params().get('OrderResultType')

	def set_OrderResultType(self,OrderResultType):
		self.add_query_param('OrderResultType',OrderResultType)

==> aliyun-python-sdk-dms-enterprise-1.7.0.tar.gz: aliyun-python-sdk-dms-enterprise-1.7.0/aliyunsdkdms_enterprise/request/v20181101/ListOrdersRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdms_enterprise.endpoint import endpoint_data

class ListOrdersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dms-enterprise', '2018-11-01', 'ListOrders')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_OrderStatus(self):
		return self.get_query_params().get('OrderStatus')

	def set_OrderStatus(self,OrderStatus):
		self.add_query_param('OrderStatus',OrderStatus)

	def get_SearchContent(self):
		return self.get_query_params().get('SearchContent')

	def set_SearchContent(self,SearchContent):
		self.add_query_param('SearchContent',SearchContent)

	def get_SearchDateType(self):
		return self.get_query_params().get('SearchDateType')

	def set_SearchDateType(self,SearchDateType):
		self.add_query_param('SearchDateType',SearchDateType)

	def get_EndTime(self):
		return self.get_query_params().get('EndTime')

	def set_EndTime(self,EndTime):
		self.add_query_param('EndTime',EndTime)

	def get_StartTime(self):
		return self.get_query_params().get('StartTime')

	def set_StartTime(self,StartTime):
		self.add_query_param('StartTime',StartTime)

	def get_Tid(self):
		return self.get_query_params().get('Tid')

	def set_Tid(self,Tid):
		self.add_query_param('Tid',Tid)

	def get_PageNumber(self):
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_query_param('PageNumber',PageNumber)

	def get_PluginType(self):
		return self.get_query_params().get('PluginType')

	def set_PluginType(self,PluginType):
		self.add_query_param('PluginType',PluginType)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_OrderResultType(self):
		return self.get_query_params().get('OrderResultType')

	def set_OrderResultType(self,OrderResultType):
		self.add_query_param('OrderResultType',OrderResultType)
